@@ -33,6 +33,7 @@
 
 typedef struct _Tabwin Tabwin;
 typedef struct _TabwinWidget TabwinWidget;
+typedef struct _TabwinWidgetClass TabwinWidgetClass;
 
 struct _Tabwin
 {
@@ -44,8 +45,8 @@ struct _Tabwin
 
 struct _TabwinWidget
 {
+    GtkWindow __parent__;
     /* The below must be freed when destroying */
-    GtkWidget *window;
     GList *widgets;
 
     /* these don't have to be */
@@ -62,6 +63,11 @@ struct _TabwinWidget
     gint grid_rows;
 };
 
+struct _TabwinWidgetClass
+{
+    GtkWindowClass __parent__;
+};
+
 Tabwin                  *tabwinCreate                           (GList **,
                                                                  GList *,
                                                                  gboolean);
@@ -69,6 +75,7 @@ Client                  *tabwinGetSelected                      (Tabwin *);
 Client                  *tabwinSelectHead                       (Tabwin *);
 Client                  *tabwinSelectNext                       (Tabwin *);
 Client                  *tabwinSelectPrev                       (Tabwin *);
+Client                  *tabwinSelectDelta                      (Tabwin *, int, int);
 Client                  *tabwinRemoveClient                     (Tabwin *,
                                                                  Client *);
 void                    tabwinDestroy                           (Tabwin *);
